@@ -242,8 +242,8 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         subs = self._stoichiometry_to_duplicate_list(stoichiometry=substrates)
         prods = self._stoichiometry_to_duplicate_list(stoichiometry=products)
 
-        subs = [j for i in substrates for j in self.isotopomers[i]]
-        prods = [j for i in products for j in self.isotopomers[i]]
+        subs = [j for i in subs for j in self.isotopomers[i]]
+        prods = [j for i in prods for j in self.isotopomers[i]]
 
         self._add_label_influx_or_efflux(
             rate_name=rate_name,
@@ -254,6 +254,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         subs = self._map_substrates_to_labelmap(substrates=subs, labelmap=labelmap)
 
         for i, (substrate, product) in enumerate(zip(subs, prods)):
+            if substrate == product:
+                warnings.warn(f"Ignoring rate {rate_name}__{i}, as substrate == product")
+                continue
             self.add_stoichiometry(rate_name=f"{rate_name}__{i}", stoichiometry={substrate: -1, product: 1})
             self.add_rate(
                 rate_name=f"{rate_name}__{i}",
